
package GLite::Data::FAS;

use strict;
no strict 'refs';
use SOAP::Lite;
use GLite::HTTPS;
use Data::Dumper;

=head1 NAME

GLite::Data::FAS

=head1 DESCRIPTION

GLite::Data::FileCatalog module provides a Perl client
library for the B<FAS> interface.

=head1 METHODS

The methods I<die> if there was a SOAP fault.
The fault string and details are added to the I<die> message.

=over 4

=item B<new($URL)>

Creates an FAS object, which is initialized with the
approriate SOAP endpoint. If the URL uses https protocol,
then it will do the HTTPS initialization (locating proxy
certificate) as well.

Note: you have to include the VO name in the URL!

    my $srv = GLite::Data::FAS->new('https://service.glite.org:8443/example');

=cut


sub new
{
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self  = {};
    $self->{SOAP} = undef;
    bless( $self, $class );

    my $url = shift;

    defined $url or 
      print STDERR "FAS endpoint was not defined!\n" and return;

    GLite::HTTPS::setEnv() if $url =~ /^https:/i;

    $self->{SOAP} = new SOAP::Lite (
        uri => 'org.glite.data.catalog',
        proxy => $url,
        on_fault => sub { my($soap, $res) = @_;
            die $soap->transport->status, "\n" unless(ref $res);
            local $Data::Dumper::Pad = "    Details: ";
            die $res->faultcode(),": ",$res->faultstring(),"\n",
                Dumper($res->faultdetail()), "\n";
        }
    );

    
    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.catalog'
    
    $self->{SOAP}->serializer()->maptype->{'Perm'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'BasicPermission'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'ACLEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'Permission'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'PermissionEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'CatalogException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'InternalException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'AuthorizationException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'ExistsException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'NotExistsException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'InvalidArgumentException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.catalog.service.fas'
    
    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_PermissionEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.fas";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_soapenc_string'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.fas";


    return $self;
}

    
=pod

=item B<addGUID(PermissionEntry[] permissions)>

=cut

sub addGUID {
    my ($self) = shift;
    my $result = $self->{SOAP}->addGUID(
        __serialize__ArrayOf_tns1_PermissionEntry('permissions', shift)
    )->result();
    return $result;
}

=pod

=item B<removeGUID(string[] guids)>

=cut

sub removeGUID {
    my ($self) = shift;
    my $result = $self->{SOAP}->removeGUID(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<checkPermission(string[] items, Perm perm)>

=cut

sub checkPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->checkPermission(
        __serialize__ArrayOf_soapenc_string('items', shift), 
        __serialize__Perm('perm', shift)
    )->result();
    return $result;
}

=pod

=item B<PermissionEntry[] getPermission(string[] items)>

=cut

sub getPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->getPermission(
        __serialize__ArrayOf_soapenc_string('items', shift)
    )->result();
    return $result;
}

=pod

=item B<setPermission(PermissionEntry[] permissions)>

=cut

sub setPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->setPermission(
        __serialize__ArrayOf_tns1_PermissionEntry('permissions', shift)
    )->result();
    return $result;
}

=pod

=item B<string getVersion()>

=cut

sub getVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVersion(
    )->result();
    return $result;
}

=pod

=item B<string getSchemaVersion()>

=cut

sub getSchemaVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getSchemaVersion(
    )->result();
    return $result;
}

=pod

=item B<string getInterfaceVersion()>

=cut

sub getInterfaceVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getInterfaceVersion(
    )->result();
    return $result;
}

=pod

=item B<string getServiceMetadata(string key)>

=cut

sub getServiceMetadata {
    my ($self) = shift;
    my $result = $self->{SOAP}->getServiceMetadata(
        SOAP::Data->new(name => 'key', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}


=pod

=back

=head1 TYPES

=over 4

=cut


    
=pod

=item B<Perm>

    my $myPerm = {
        permission => $myboolean, 
        remove => $myboolean, 
        read => $myboolean, 
        write => $myboolean, 
        list => $myboolean, 
        execute => $myboolean, 
        getMetadata => $myboolean, 
        setMetadata => $myboolean
    };

=cut

sub __serialize__Perm {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Perm';
    my $value    = shift || {};

    
    $value->{'permission'} = SOAP::Data->new (
        name => 'permission',
        type => 'xsd:boolean',
        value => $rawValue->{'permission'}
    );

    $value->{'remove'} = SOAP::Data->new (
        name => 'remove',
        type => 'xsd:boolean',
        value => $rawValue->{'remove'}
    );

    $value->{'read'} = SOAP::Data->new (
        name => 'read',
        type => 'xsd:boolean',
        value => $rawValue->{'read'}
    );

    $value->{'write'} = SOAP::Data->new (
        name => 'write',
        type => 'xsd:boolean',
        value => $rawValue->{'write'}
    );

    $value->{'list'} = SOAP::Data->new (
        name => 'list',
        type => 'xsd:boolean',
        value => $rawValue->{'list'}
    );

    $value->{'execute'} = SOAP::Data->new (
        name => 'execute',
        type => 'xsd:boolean',
        value => $rawValue->{'execute'}
    );

    $value->{'getMetadata'} = SOAP::Data->new (
        name => 'getMetadata',
        type => 'xsd:boolean',
        value => $rawValue->{'getMetadata'}
    );

    $value->{'setMetadata'} = SOAP::Data->new (
        name => 'setMetadata',
        type => 'xsd:boolean',
        value => $rawValue->{'setMetadata'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<BasicPermission>

    my $myBasicPermission = {
        userName => 'string', 
        groupName => 'string', 
        userPerm => $myPerm, 
        groupPerm => $myPerm, 
        otherPerm => $myPerm
    };

=cut

sub __serialize__BasicPermission {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'BasicPermission';
    my $value    = shift || {};

    
    $value->{'userName'} = SOAP::Data->new (
        name => 'userName',
        type => 'xsd:string',
        value => $rawValue->{'userName'}
    );

    $value->{'groupName'} = SOAP::Data->new (
        name => 'groupName',
        type => 'xsd:string',
        value => $rawValue->{'groupName'}
    );

    $value->{'userPerm'} = __serialize__Perm('userPerm', $rawValue->{'userPerm'});

    $value->{'groupPerm'} = __serialize__Perm('groupPerm', $rawValue->{'groupPerm'});

    $value->{'otherPerm'} = __serialize__Perm('otherPerm', $rawValue->{'otherPerm'});


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<ACLEntry>

    my $myACLEntry = {
        principalPerm => $myPerm, 
        principal => 'string'
    };

=cut

sub __serialize__ACLEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ACLEntry';
    my $value    = shift || {};

    
    $value->{'principalPerm'} = __serialize__Perm('principalPerm', $rawValue->{'principalPerm'});

    $value->{'principal'} = SOAP::Data->new (
        name => 'principal',
        type => 'xsd:string',
        value => $rawValue->{'principal'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<Permission>

    my $myPermission = new BasicPermission (
        
    );

=cut

sub __serialize__Permission {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Permission';
    my $value    = shift || {};

    
    $value->{'acl'} = SOAP::Data->new (
        name => 'acl',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'ACLEntry'},
        value => [ map { __serialize__ACLEntry(undef, $_); } @{$rawValue->{'acl'}} ]
    );


    # calling the superclass' serializer for the rest
    return __serialize__BasicPermission ($name, $rawValue, $type, $value);
}

=pod

=item B<PermissionEntry>

    my $myPermissionEntry = {
        item => 'string', 
        permission => $myPermission
    };

=cut

sub __serialize__PermissionEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'PermissionEntry';
    my $value    = shift || {};

    
    $value->{'item'} = SOAP::Data->new (
        name => 'item',
        type => 'xsd:string',
        value => $rawValue->{'item'}
    );

    $value->{'permission'} = __serialize__Permission('permission', $rawValue->{'permission'});


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<CatalogException>

    my $myCatalogException = {
        message => 'string'
    };

=cut

sub __serialize__CatalogException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'CatalogException';
    my $value    = shift || {};

    
    $value->{'message'} = SOAP::Data->new (
        name => 'message',
        type => 'xsd:string',
        value => $rawValue->{'message'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<InternalException>

    my $myInternalException = new CatalogException (
        
    );

=cut

sub __serialize__InternalException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InternalException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<AuthorizationException>

    my $myAuthorizationException = new CatalogException (
        
    );

=cut

sub __serialize__AuthorizationException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'AuthorizationException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<ExistsException>

    my $myExistsException = new CatalogException (
        
    );

=cut

sub __serialize__ExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<NotExistsException>

    my $myNotExistsException = new CatalogException (
        
    );

=cut

sub __serialize__NotExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'NotExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<InvalidArgumentException>

    my $myInvalidArgumentException = new CatalogException (
        
    );

=cut

sub __serialize__InvalidArgumentException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InvalidArgumentException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<ArrayOf_tns1_PermissionEntry>

    my $myArrayOf_tns1_PermissionEntry = [ $myPermissionEntry1, $myPermissionEntry2, ... ];

=cut

sub __serialize__ArrayOf_tns1_PermissionEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_PermissionEntry';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'PermissionEntry'},
        value => [ map { __serialize__PermissionEntry(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_soapenc_string>

    my $myArrayOf_soapenc_string = [ 'string1', 'string2', ...];

=cut

sub __serialize__ArrayOf_soapenc_string {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_soapenc_string';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue} ]
    );
}



=pod

=back

=head1 SEE ALSO

L<GLite::HTTPS>

=head1 AUTHORS

Copyright (c) 2004 CERN, on behalf of the EU EGEE project.
For license conditions see LICENSE file or
L<http://www.edg.org/license.html>.

=cut

1;
